{% if togglable_colums %}
<label class="form-label pt-3" for="column_selector">Select additional columns:</label>
<select class="form-control mb-3" multiple name="columns" id="column_selector">
    {% for key, value in togglable_colums.items %}
    {% if key == 'merge' and user.is_authenticated and enable_merge %}
    <option value="{{ key }}">
        {{ value }}
    </option>
    {% elif key == 'merge' and not user.is_authenticated %}
    {% elif key != 'merge' %}
    <option value="{{ key }}">
        {{ value }}
    </option>
    {% endif %}
    {% endfor %}
</select>
{% else %}
{% endif %}