<div class="pt-2 ps-5">
  <nav style="--bs-breadcrumb-divider: '>';" aria-label="breadcrumb">
      <ol class="breadcrumb">
        <li class="breadcrumb-item"><a href="/">Home</a></li>
        <li class="breadcrumb-item active">{{ verbose_name_plural }}</li>
      </ol>
  </nav>
</div>